==> azureus_2.5.0.0+0.orig.tar.gz: azureus-2.5.0.0.orig/com/aelitis/azureus/core/dht/speed/DHTSpeedTesterContact.java <==
/*
 * Created on 15-Mar-2006
 * Created by Paul Gardner
 * Copyright (C) 2006 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SAS au capital de 46,603.30 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */

package com.aelitis.azureus.core.dht.speed;

import com.aelitis.azureus.core.dht.transport.DHTTransportContact;

public interface 
DHTSpeedTesterContact 
{
	public DHTTransportContact
	getContact();
	
	public int
	getPingPeriod();
	
	public void
	setPingPeriod(
		int		period_secs );
	
		/**
		 * If you don't like the ping times from this contact you can always kill it, a new one will be
		 * created in its place
		 */
	
	public void
	destroy();
	
	public void
	addListener(
		DHTSpeedTesterContactListener	listener );
	
	public void
	removeListener(
		DHTSpeedTesterContactListener	listener );
}

==> azureus_4.3.0.6.orig.tar.gz: azureus-4.3.0.6/com/aelitis/azureus/core/dht/speed/DHTSpeedTesterContact.java <==
/*
 * Created on 15-Mar-2006
 * Created by Paul Gardner
 * Copyright (C) 2006 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SAS au capital de 46,603.30 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */

package com.aelitis.azureus.core.dht.speed;

import java.net.InetSocketAddress;

public interface 
DHTSpeedTesterContact 
{
	public InetSocketAddress
	getAddress();
	
	public int
	getPingPeriod();
	
	public void
	setPingPeriod(
		int		period_secs );
	
		/**
		 * If you don't like the ping times from this contact you can always kill it, a new one will be
		 * created in its place
		 */
	
	public void
	destroy();
	
	public void
	addListener(
		DHTSpeedTesterContactListener	listener );
	
	public void
	removeListener(
		DHTSpeedTesterContactListener	listener );
	
	public String
	getString();
}
